#!/bin/bash

instances_used=`grep '\[' mysqld_multi.conf | tr -d '\[' | tr -d '\]' | grep -v mysqld_multi | sed 's/mysqld//g' | sort -n`
echo "Instance names: "$instances_used
echo

ports_used=`grep port mysqld_multi.conf | cut -d= -f2 | sort -n`
echo "Ports used: "$ports_used
echo

echo -n "Version: mysql-"
read version
echo -n "Port   : "
read port
echo -n "Name   : mysqld"
read name
name="mysqld$name"

cnt=`grep port mysqld_multi.conf | grep -c $port`

if [ "$cnt" != '0' ] ; then
  echo "Port $port is already in use. Abort."
  exit 1
fi

cnt=`grep -c "$name" mysqld_multi.conf`

if [ "$cnt" != '0' ] ; then
  echo "Name $name is already in use. Abort."
  exit 1
fi

datadir="/home/mysql/data/$name"
basedir="/home/mysql/product/mysql-$version"
language=`find $basedir/ -name errmsg.sys | grep english`
language=`dirname $language`

echo
echo "Please check: "
echo

echo ""
echo "[$name]"
echo ""
echo "# must be at first position"
echo "defaults-file = $datadir/my.cnf"
echo "ledir         = $basedir"
echo "mysqld        = $basedir/bin/mysqld_safe"
echo "mysqladmin    = $basedir/bin/mysqladmin"
echo "language      = $language"
echo ""
echo "port          = $port"
echo "socket        = /home/mysql/run/mysql-$port.sock"
echo "pid-file      = /home/mysql/run/mysql-$port.pid"
echo "datadir       = $datadir"
echo ""

echo -n "OK [y/n]: "
read answer
echo

if [ "$answer" != 'y' ] ; then
  echo "Abort."
  exit 2
fi

echo "writing..."

# this is redundant code!!! error prone avoid!

echo "" >>mysqld_multi.conf
echo "[$name]" >>mysqld_multi.conf
echo "" >>mysqld_multi.conf
echo "# must be at first position" >>mysqld_multi.conf
echo "defaults-file = $datadir/my.cnf" >>mysqld_multi.conf
echo "ledir         = $basedir/bin" >>mysqld_multi.conf
echo "mysqld        = $basedir/bin/mysqld_safe" >>mysqld_multi.conf
echo "mysqladmin    = $basedir/bin/mysqladmin" >>mysqld_multi.conf
echo "language      = $language" >>mysqld_multi.conf
echo "" >>mysqld_multi.conf
echo "port          = $port" >>mysqld_multi.conf
echo "socket        = /home/mysql/run/mysql-$port.sock" >>mysqld_multi.conf
echo "pid-file      = /home/mysql/run/mysql-$port.pid" >>mysqld_multi.conf
echo "datadir       = $datadir" >>mysqld_multi.conf
echo "" >>mysqld_multi.conf


echo "Copy template ..."
echo
mkdir -p $datadir

echo "[client]" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "port                          = $port" >>$datadir/my.cnf
echo "socket                        = /home/mysql/run/mysql-$port.sock" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "[mysqld]" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "port                          = $port" >>$datadir/my.cnf
echo "socket                        = /home/mysql/run/mysql-$port.sock" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "log-error                     = error.log" >>$datadir/my.cnf
echo "log-warnings                  = 2" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "server-id                     = $port" >>$datadir/my.cnf
echo "log-bin                       = bin-log" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "general-log                   = 1" >>$datadir/my.cnf
echo "general-log-file              = general.log" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf
echo "slow_query_log         = slow.log" >>$datadir/my.cnf
echo "" >>$datadir/my.cnf

echo "Installing DB:"
echo "$basedir/scripts/mysql_install_db --datadir=$datadir"
cd $basedir
./scripts/mysql_install_db --datadir=$datadir
cd -

echo "Please source the env now as follows: . ~/.profile ; $name"
echo

